Merge branch 't/writer_setup_cleanup'
[paraslash.git] / aft.c
diff --git a/aft.c b/aft.c
index b3dde1379997bb6f69647255d0ac53fb703fce09..f4080233855009be5423b3bc9325b861d5f20b0c 100644 (file)
--- a/aft.c
+++ b/aft.c
@@ -7,8 +7,6 @@
 /** \file aft.c Audio file table functions. */
 
 #include <regex.h>
-#include <dirent.h> /* readdir() */
-#include <openssl/rc4.h>
 #include <sys/mman.h>
 #include <fnmatch.h>
 #include <sys/shm.h>
@@ -20,7 +18,6 @@
 #include "string.h"
 #include "afh.h"
 #include "afs.h"
-#include "net.h"
 #include "fd.h"
 #include "ipc.h"
 #include "portable_io.h"
@@ -239,7 +236,7 @@ enum audio_file_table_columns {
  */
 static int aft_hash_compare(const struct osl_object *obj1, const struct osl_object *obj2)
 {
-       return hash_compare((HASH_TYPE *)obj1->data, (HASH_TYPE *)obj2->data);
+       return hash_compare((unsigned char *)obj1->data, (unsigned char *)obj2->data);
 }
 
 static struct osl_column_description aft_cols[] = {
@@ -486,7 +483,7 @@ int aft_get_row_of_path(const char *path, struct osl_row **row)
  *
  * \return Standard.
  */
-static int aft_get_row_of_hash(HASH_TYPE *hash, struct osl_row **row)
+static int aft_get_row_of_hash(unsigned char *hash, struct osl_row **row)
 {
        const struct osl_object obj = {.data = hash, .size = HASH_SIZE};
        return osl(osl_get_row(audio_file_table, AFTCOL_HASH, &obj, row));
@@ -606,7 +603,7 @@ static int get_hash_object_of_aft_row(const struct osl_row *row,
  * \return The return value of the underlying call to
  * get_hash_object_of_aft_row().
  */
-static int get_hash_of_row(const struct osl_row *row, HASH_TYPE **hash)
+static int get_hash_of_row(const struct osl_row *row, unsigned char **hash)
 {
        struct osl_object obj;
        int ret = get_hash_object_of_aft_row(row, &obj);
@@ -725,7 +722,7 @@ static int get_local_time(uint64_t *seconds, char *buf, size_t size,
                } \
        }
 
-static short unsigned get_duration_width(int seconds)
+__a_const static short unsigned get_duration_width(int seconds)
 {
        short unsigned width;
        unsigned hours = seconds / 3600, mins = (seconds % 3600) / 60;
@@ -1027,7 +1024,7 @@ out:
 
 static int make_status_items(struct audio_file_data *afd,
                struct afs_info *afsi, char *path, long score,
-               HASH_TYPE *hash)
+               unsigned char *hash)
 {
        struct ls_data d = {
                .afhi = afd->afhi,
@@ -1080,7 +1077,7 @@ static int make_status_items(struct audio_file_data *afd,
 int open_and_update_audio_file(struct osl_row *aft_row, long score,
        struct audio_file_data *afd)
 {
-       HASH_TYPE *aft_hash, file_hash[HASH_SIZE];
+       unsigned char *aft_hash, file_hash[HASH_SIZE];
        struct osl_object afsi_obj;
        struct afs_info old_afsi, new_afsi;
        int ret = get_hash_of_row(aft_row, &aft_hash);
@@ -1397,7 +1394,7 @@ out:
 /*
  * TODO: flags -h (sort by hash)
  */
-int com_ls(struct rc4_context *rc4c, int argc, char * const * const argv)
+int com_ls(struct stream_cipher_context *scc, int argc, char * const * const argv)
 {
        int i, ret;
        unsigned flags = 0;
@@ -1509,7 +1506,7 @@ int com_ls(struct rc4_context *rc4c, int argc, char * const * const argv)
        opts.mode = mode;
        opts.num_patterns = argc - i;
        ret = send_option_arg_callback_request(&query, opts.num_patterns,
-               argv + i, com_ls_callback, rc4_send_result, rc4c);
+               argv + i, com_ls_callback, sc_send_result, scc);
        return ret;
 }
 
@@ -1527,7 +1524,7 @@ int audio_file_loop(void *private_data, osl_rbtree_loop_func *func)
                func));
 }
 
-static struct osl_row *find_hash_sister(HASH_TYPE *hash)
+static struct osl_row *find_hash_sister(unsigned char *hash)
 {
        const struct osl_object obj = {.data = hash, .size = HASH_SIZE};
        struct osl_row *row;
@@ -1559,7 +1556,7 @@ enum com_add_buffer_offsets {
  * It's OK to call this with afhi == NULL. In this case, the audio format
  * handler info won't be stored in the buffer.
  */
-static void save_add_callback_buffer(HASH_TYPE *hash, const char *path,
+static void save_add_callback_buffer(unsigned char *hash, const char *path,
                struct afh_info *afhi, uint32_t flags,
                uint8_t audio_format_num, struct osl_object *obj)
 {
@@ -1662,7 +1659,7 @@ static void com_add_callback(int fd, const struct osl_object *query)
        struct osl_row *pb, *aft_row;
        struct osl_row *hs;
        struct osl_object objs[NUM_AFT_COLUMNS];
-       HASH_TYPE *hash;
+       unsigned char *hash;
        char asc[2 * HASH_SIZE + 1];
        int ret;
        char afsi_buf[AFSI_SIZE];
@@ -1672,7 +1669,7 @@ static void com_add_callback(int fd, const struct osl_object *query)
                .max_size_handler = pass_buffer_as_shm, .private_data = &fd};
        uint16_t afhi_offset, chunks_offset;
 
-       hash = (HASH_TYPE *)buf + CAB_HASH_OFFSET;
+       hash = (unsigned char *)buf + CAB_HASH_OFFSET;
        hash_to_asc(hash, asc);;
        objs[AFTCOL_HASH].data = buf + CAB_HASH_OFFSET;
        objs[AFTCOL_HASH].size = HASH_SIZE;
@@ -1737,7 +1734,7 @@ static void com_add_callback(int fd, const struct osl_object *query)
        objs[AFTCOL_CHUNKS].size = query->size - chunks_offset;
        if (pb && !hs) { /* update pb's hash */
                char old_asc[2 * HASH_SIZE + 1];
-               HASH_TYPE *old_hash;
+               unsigned char *old_hash;
                ret = get_hash_of_row(pb, &old_hash);
                if (ret < 0)
                        goto out;
@@ -1796,8 +1793,8 @@ out:
 
 /** Used by com_add(). */
 struct private_add_data {
-       /** The socket file descriptor, including rc4 keys. */
-       struct rc4_context *rc4c;
+       /** The socket file descriptor, including stream cipher keys. */
+       struct stream_cipher_context *scc;
        /** The given add flags. */
        uint32_t flags;
 };
@@ -1814,7 +1811,7 @@ static void path_brother_callback(int fd, const struct osl_object *query)
 
 static void hash_sister_callback(int fd, const struct osl_object *query)
 {
-       HASH_TYPE *hash = query->data;
+       unsigned char *hash = query->data;
        struct osl_row *hash_sister;
 
        hash_sister = find_hash_sister(hash);
@@ -1826,7 +1823,7 @@ static void hash_sister_callback(int fd, const struct osl_object *query)
 static int get_row_pointer_from_result(struct osl_object *result, void *private)
 {
        struct osl_row **row = private;
-       *row = result->data;
+       *row = *(struct osl_row **)(result->data);
        return 1;
 }
 
@@ -1838,7 +1835,7 @@ static int add_one_audio_file(const char *path, void *private_data)
        struct afh_info afhi, *afhi_ptr = NULL;
        struct osl_row *pb = NULL, *hs = NULL; /* path brother/hash sister */
        struct osl_object map, obj = {.data = NULL}, query;
-       HASH_TYPE hash[HASH_SIZE];
+       unsigned char hash[HASH_SIZE];
 
        ret = guess_audio_format(path);
        if (ret < 0 && !(pad->flags & ADD_FLAG_ALL))
@@ -1852,7 +1849,7 @@ static int add_one_audio_file(const char *path, void *private_data)
        ret = 1;
        if (pb && (pad->flags & ADD_FLAG_LAZY)) { /* lazy is really cheap */
                if (pad->flags & ADD_FLAG_VERBOSE)
-                       send_ret = rc4_send_va_buffer(pad->rc4c,
+                       send_ret = sc_send_va_buffer(pad->scc,
                                "lazy-ignore: %s\n", path);
                goto out_free;
        }
@@ -1873,7 +1870,7 @@ static int add_one_audio_file(const char *path, void *private_data)
        ret = 1;
        if (pb && hs && hs == pb && !(pad->flags & ADD_FLAG_FORCE)) {
                if (pad->flags & ADD_FLAG_VERBOSE)
-                       send_ret = rc4_send_va_buffer(pad->rc4c,
+                       send_ret = sc_send_va_buffer(pad->scc,
                                "%s exists, not forcing update\n", path);
                goto out_unmap;
        }
@@ -1891,13 +1888,13 @@ static int add_one_audio_file(const char *path, void *private_data)
        munmap(map.data, map.size);
        close(fd);
        if (pad->flags & ADD_FLAG_VERBOSE) {
-               send_ret = rc4_send_va_buffer(pad->rc4c, "adding %s\n", path);
+               send_ret = sc_send_va_buffer(pad->scc, "adding %s\n", path);
                if (send_ret < 0)
                        goto out_free;
        }
        save_add_callback_buffer(hash, path, afhi_ptr, pad->flags, format_num, &obj);
        /* Ask afs to consider this entry for adding. */
-       ret = send_callback_request(com_add_callback, &obj, rc4_send_result, pad->rc4c);
+       ret = send_callback_request(com_add_callback, &obj, sc_send_result, pad->scc);
        goto out_free;
 
 out_unmap:
@@ -1905,7 +1902,7 @@ out_unmap:
        munmap(map.data, map.size);
 out_free:
        if (ret < 0 && send_ret >= 0)
-               send_ret = rc4_send_va_buffer(pad->rc4c,
+               send_ret = sc_send_va_buffer(pad->scc,
                        "failed to add %s (%s)\n", path, para_strerror(-ret));
        free(obj.data);
        if (afhi_ptr) {
@@ -1921,10 +1918,10 @@ out_free:
        return send_ret;
 }
 
-int com_add(struct rc4_context *rc4c, int argc, char * const * const argv)
+int com_add(struct stream_cipher_context *scc, int argc, char * const * const argv)
 {
        int i, ret;
-       struct private_add_data pad = {.rc4c = rc4c, .flags = 0};
+       struct private_add_data pad = {.scc = scc, .flags = 0};
        struct stat statbuf;
 
        for (i = 1; i < argc; i++) {
@@ -1958,7 +1955,7 @@ int com_add(struct rc4_context *rc4c, int argc, char * const * const argv)
                char *path;
                ret = verify_path(argv[i], &path);
                if (ret < 0) {
-                       ret = rc4_send_va_buffer(rc4c, "%s: %s\n", argv[i],
+                       ret = sc_send_va_buffer(scc, "%s: %s\n", argv[i],
                                para_strerror(-ret));
                        if (ret < 0)
                                return ret;
@@ -1966,7 +1963,7 @@ int com_add(struct rc4_context *rc4c, int argc, char * const * const argv)
                }
                ret = stat(path, &statbuf);
                if (ret < 0) {
-                       ret = rc4_send_va_buffer(rc4c, "failed to stat %s (%s)\n", path,
+                       ret = sc_send_va_buffer(scc, "failed to stat %s (%s)\n", path,
                                strerror(errno));
                        free(path);
                        if (ret < 0)
@@ -1979,7 +1976,7 @@ int com_add(struct rc4_context *rc4c, int argc, char * const * const argv)
                else
                        ret = add_one_audio_file(path, &pad);
                if (ret < 0) {
-                       rc4_send_va_buffer(rc4c, "%s: %s\n", path, para_strerror(-ret));
+                       sc_send_va_buffer(scc, "%s: %s\n", path, para_strerror(-ret));
                        free(path);
                        return ret;
                }
@@ -2111,7 +2108,7 @@ static void com_touch_callback(int fd, const struct osl_object *query)
        free(tad.pb.buf);
 }
 
-int com_touch(struct rc4_context *rc4c, int argc, char * const * const argv)
+int com_touch(struct stream_cipher_context *scc, int argc, char * const * const argv)
 {
        struct com_touch_options cto = {
                .num_played = -1,
@@ -2179,9 +2176,9 @@ int com_touch(struct rc4_context *rc4c, int argc, char * const * const argv)
        if (i >= argc)
                return -E_AFT_SYNTAX;
        ret = send_option_arg_callback_request(&query, argc - i,
-               argv + i, com_touch_callback, rc4_send_result, rc4c);
+               argv + i, com_touch_callback, sc_send_result, scc);
        if (ret < 0)
-               rc4_send_va_buffer(rc4c, "%s\n", para_strerror(-ret));
+               sc_send_va_buffer(scc, "%s\n", para_strerror(-ret));
        return ret;
 }
 
@@ -2263,7 +2260,7 @@ static void com_rm_callback(int fd, const struct osl_object *query)
 }
 
 /* TODO options: -r (recursive) */
-int com_rm(struct rc4_context *rc4c, int argc,  char * const * const argv)
+int com_rm(struct stream_cipher_context *scc, int argc,  char * const * const argv)
 {
        uint32_t flags = 0;
        struct osl_object query = {.data = &flags, .size = sizeof(flags)};
@@ -2294,9 +2291,9 @@ int com_rm(struct rc4_context *rc4c, int argc,  char * const * const argv)
        if (i >= argc)
                return -E_AFT_SYNTAX;
        ret = send_option_arg_callback_request(&query, argc - i, argv + i,
-               com_rm_callback, rc4_send_result, rc4c);
+               com_rm_callback, sc_send_result, scc);
        if (ret < 0)
-               rc4_send_va_buffer(rc4c, "%s\n", para_strerror(-ret));
+               sc_send_va_buffer(scc, "%s\n", para_strerror(-ret));
        return ret;
 }
 
@@ -2411,7 +2408,7 @@ out:
        free(cad.pb.buf);
 }
 
-int com_cpsi(struct rc4_context *rc4c, int argc,  char * const * const argv)
+int com_cpsi(struct stream_cipher_context *scc, int argc,  char * const * const argv)
 {
        unsigned flags = 0;
        int i, ret;
@@ -2456,9 +2453,9 @@ int com_cpsi(struct rc4_context *rc4c, int argc,  char * const * const argv)
        if (!(flags & ~CPSI_FLAG_VERBOSE)) /* no copy flags given */
                flags = ~(unsigned)CPSI_FLAG_VERBOSE | flags;
        ret = send_option_arg_callback_request(&options, argc - i, argv + i,
-               com_cpsi_callback, rc4_send_result, rc4c);
+               com_cpsi_callback, sc_send_result, scc);
        if (ret < 0)
-               rc4_send_va_buffer(rc4c, "%s\n", para_strerror(-ret));
+               sc_send_va_buffer(scc, "%s\n", para_strerror(-ret));
        return ret;
 }
 
@@ -2474,9 +2471,9 @@ static void afs_stat_callback(int fd, const struct osl_object *query)
 }
 
 /**
- * Get the current afs status items from the afs process and send it using RC4.
+ * Get the current afs status items from the afs process and send it.
  *
* \param rc4c The rc4 context for data encryption.
  * \param parser_friendly Whether parser-friendly output format should be used.
  *
  * As the contents of the afs status items change in time and the command
@@ -2485,12 +2482,12 @@ static void afs_stat_callback(int fd, const struct osl_object *query)
  * is used to pass the status items from the afs process to the command handler
  * via a shared memory area and a pipe.
  */
-int send_afs_status(struct rc4_context *rc4c, int parser_friendly)
+int send_afs_status(struct stream_cipher_context *scc, int parser_friendly)
 {
        struct osl_object query = {.data = &parser_friendly,
                .size = sizeof(parser_friendly)};
 
-       return send_callback_request(afs_stat_callback, &query, rc4_send_result, rc4c);
+       return send_callback_request(afs_stat_callback, &query, sc_send_result, scc);
 }
 
 /* TODO: optionally fix problems by removing offending rows */
@@ -2571,10 +2568,6 @@ static void aft_close(void)
 {
        osl_close_table(audio_file_table, OSL_MARK_CLEAN);
        audio_file_table = NULL;
-       free(status_items);
-       status_items = NULL;
-       free(parser_friendly_status_items);
-       parser_friendly_status_items = NULL;
 }
 
 /**
@@ -2474,9 +2471,9 @@ static void afs_stat_callback(int fd, const struct osl_object *query)
  *
- * \param rc4c The rc4 context for data encryption.
+ * \param scc The stream cipher context for data encryption.
  * \param parser_friendly Whether parser-friendly output format should be used.
  *